@@ -5,7 +5,7 @@ use warnings;
 package Log::Any;
 
 # ABSTRACT: Bringing loggers and listeners together
-our $VERSION = '1.705';
+our $VERSION = '1.708';
 
 use Log::Any::Manager;
 use Log::Any::Proxy::Null;
@@ -134,7 +134,7 @@ Log::Any - Bringing loggers and listeners together
 
 =head1 VERSION
 
-version 1.705
+version 1.708
 
 =head1 SYNOPSIS
 
@@ -475,7 +475,7 @@ Stephen Thirlwall <sdt@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords bj5004 cm-perl Karen Etheridge Konstantin S. Uvarin Lucas Kanashiro Maros Kollar Maxim Vuets mephinet Nick Tonkin Philipp Gortan Phill Legault Shlomi Fish
+=for stopwords bj5004 cm-perl Jonathan Karen Etheridge Konstantin S. Uvarin Lucas Kanashiro Maros Kollar Maxim Vuets mephinet Michael Conrad Nick Tonkin Paul Durden Philipp Gortan Phill Legault Shlomi Fish
 
 =over 4
 
@@ -489,6 +489,10 @@ cm-perl <cm-perl@users.noreply.github.com>
 
 =item *
 
+Jonathan <jjrs.pam+github@gmail.com>
+
+=item *
+
 Karen Etheridge <ether@cpan.org>
 
 =item *
@@ -513,10 +517,18 @@ mephinet <mephinet@gmx.net>
 
 =item *
 
+Michael Conrad <mconrad@intellitree.com>
+
+=item *
+
 Nick Tonkin <1nickt@users.noreply.github.com>
 
 =item *
 
+Paul Durden <alabamapaul@gmail.com>
+
+=item *
+
 Philipp Gortan <philipp.gortan@apa.at>
 
 =item *
